# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class LiveTvSeriesTimerInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'channel_id': 'str',
        'channel_ids': 'list[str]',
        'parent_folder_id': 'int',
        'program_id': 'str',
        'name': 'str',
        'service_name': 'str',
        'overview': 'str',
        'start_date': 'datetime',
        'end_date': 'datetime',
        'record_any_time': 'bool',
        'keep_up_to': 'int',
        'keep_until': 'LiveTvKeepUntil',
        'skip_episodes_in_library': 'bool',
        'match_existing_items_with_any_library': 'bool',
        'record_new_only': 'bool',
        'days': 'list[DayOfWeek]',
        'priority': 'int',
        'pre_padding_seconds': 'int',
        'post_padding_seconds': 'int',
        'is_pre_padding_required': 'bool',
        'is_post_padding_required': 'bool',
        'series_id': 'str',
        'provider_ids': 'ProviderIdDictionary',
        'max_recording_seconds': 'int',
        'keywords': 'list[LiveTvKeywordInfo]',
        'timer_type': 'LiveTvTimerType'
    }

    attribute_map = {
        'id': 'Id',
        'channel_id': 'ChannelId',
        'channel_ids': 'ChannelIds',
        'parent_folder_id': 'ParentFolderId',
        'program_id': 'ProgramId',
        'name': 'Name',
        'service_name': 'ServiceName',
        'overview': 'Overview',
        'start_date': 'StartDate',
        'end_date': 'EndDate',
        'record_any_time': 'RecordAnyTime',
        'keep_up_to': 'KeepUpTo',
        'keep_until': 'KeepUntil',
        'skip_episodes_in_library': 'SkipEpisodesInLibrary',
        'match_existing_items_with_any_library': 'MatchExistingItemsWithAnyLibrary',
        'record_new_only': 'RecordNewOnly',
        'days': 'Days',
        'priority': 'Priority',
        'pre_padding_seconds': 'PrePaddingSeconds',
        'post_padding_seconds': 'PostPaddingSeconds',
        'is_pre_padding_required': 'IsPrePaddingRequired',
        'is_post_padding_required': 'IsPostPaddingRequired',
        'series_id': 'SeriesId',
        'provider_ids': 'ProviderIds',
        'max_recording_seconds': 'MaxRecordingSeconds',
        'keywords': 'Keywords',
        'timer_type': 'TimerType'
    }

    def __init__(self, id=None, channel_id=None, channel_ids=None, parent_folder_id=None, program_id=None, name=None, service_name=None, overview=None, start_date=None, end_date=None, record_any_time=None, keep_up_to=None, keep_until=None, skip_episodes_in_library=None, match_existing_items_with_any_library=None, record_new_only=None, days=None, priority=None, pre_padding_seconds=None, post_padding_seconds=None, is_pre_padding_required=None, is_post_padding_required=None, series_id=None, provider_ids=None, max_recording_seconds=None, keywords=None, timer_type=None):  # noqa: E501
        """LiveTvSeriesTimerInfo - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._channel_id = None
        self._channel_ids = None
        self._parent_folder_id = None
        self._program_id = None
        self._name = None
        self._service_name = None
        self._overview = None
        self._start_date = None
        self._end_date = None
        self._record_any_time = None
        self._keep_up_to = None
        self._keep_until = None
        self._skip_episodes_in_library = None
        self._match_existing_items_with_any_library = None
        self._record_new_only = None
        self._days = None
        self._priority = None
        self._pre_padding_seconds = None
        self._post_padding_seconds = None
        self._is_pre_padding_required = None
        self._is_post_padding_required = None
        self._series_id = None
        self._provider_ids = None
        self._max_recording_seconds = None
        self._keywords = None
        self._timer_type = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if channel_id is not None:
            self.channel_id = channel_id
        if channel_ids is not None:
            self.channel_ids = channel_ids
        if parent_folder_id is not None:
            self.parent_folder_id = parent_folder_id
        if program_id is not None:
            self.program_id = program_id
        if name is not None:
            self.name = name
        if service_name is not None:
            self.service_name = service_name
        if overview is not None:
            self.overview = overview
        if start_date is not None:
            self.start_date = start_date
        if end_date is not None:
            self.end_date = end_date
        if record_any_time is not None:
            self.record_any_time = record_any_time
        if keep_up_to is not None:
            self.keep_up_to = keep_up_to
        if keep_until is not None:
            self.keep_until = keep_until
        if skip_episodes_in_library is not None:
            self.skip_episodes_in_library = skip_episodes_in_library
        if match_existing_items_with_any_library is not None:
            self.match_existing_items_with_any_library = match_existing_items_with_any_library
        if record_new_only is not None:
            self.record_new_only = record_new_only
        if days is not None:
            self.days = days
        if priority is not None:
            self.priority = priority
        if pre_padding_seconds is not None:
            self.pre_padding_seconds = pre_padding_seconds
        if post_padding_seconds is not None:
            self.post_padding_seconds = post_padding_seconds
        if is_pre_padding_required is not None:
            self.is_pre_padding_required = is_pre_padding_required
        if is_post_padding_required is not None:
            self.is_post_padding_required = is_post_padding_required
        if series_id is not None:
            self.series_id = series_id
        if provider_ids is not None:
            self.provider_ids = provider_ids
        if max_recording_seconds is not None:
            self.max_recording_seconds = max_recording_seconds
        if keywords is not None:
            self.keywords = keywords
        if timer_type is not None:
            self.timer_type = timer_type

    @property
    def id(self):
        """Gets the id of this LiveTvSeriesTimerInfo.  # noqa: E501

        Id of the recording.  # noqa: E501

        :return: The id of this LiveTvSeriesTimerInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this LiveTvSeriesTimerInfo.

        Id of the recording.  # noqa: E501

        :param id: The id of this LiveTvSeriesTimerInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def channel_id(self):
        """Gets the channel_id of this LiveTvSeriesTimerInfo.  # noqa: E501

        ChannelId of the recording.  # noqa: E501

        :return: The channel_id of this LiveTvSeriesTimerInfo.  # noqa: E501
        :rtype: str
        """
        return self._channel_id

    @channel_id.setter
    def channel_id(self, channel_id):
        """Sets the channel_id of this LiveTvSeriesTimerInfo.

        ChannelId of the recording.  # noqa: E501

        :param channel_id: The channel_id of this LiveTvSeriesTimerInfo.  # noqa: E501
        :type: str
        """

        self._channel_id = channel_id

    @property
    def channel_ids(self):
        """Gets the channel_ids of this LiveTvSeriesTimerInfo.  # noqa: E501


        :return: The channel_ids of this LiveTvSeriesTimerInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._channel_ids

    @channel_ids.setter
    def channel_ids(self, channel_ids):
        """Sets the channel_ids of this LiveTvSeriesTimerInfo.


        :param channel_ids: The channel_ids of this LiveTvSeriesTimerInfo.  # noqa: E501
        :type: list[str]
        """

        self._channel_ids = channel_ids

    @property
    def parent_folder_id(self):
        """Gets the parent_folder_id of this LiveTvSeriesTimerInfo.  # noqa: E501


        :return: The parent_folder_id of this LiveTvSeriesTimerInfo.  # noqa: E501
        :rtype: int
        """
        return self._parent_folder_id

    @parent_folder_id.setter
    def parent_folder_id(self, parent_folder_id):
        """Sets the parent_folder_id of this LiveTvSeriesTimerInfo.


        :param parent_folder_id: The parent_folder_id of this LiveTvSeriesTimerInfo.  # noqa: E501
        :type: int
        """

        self._parent_folder_id = parent_folder_id

    @property
    def program_id(self):
        """Gets the program_id of this LiveTvSeriesTimerInfo.  # noqa: E501

        The program identifier.  # noqa: E501

        :return: The program_id of this LiveTvSeriesTimerInfo.  # noqa: E501
        :rtype: str
        """
        return self._program_id

    @program_id.setter
    def program_id(self, program_id):
        """Sets the program_id of this LiveTvSeriesTimerInfo.

        The program identifier.  # noqa: E501

        :param program_id: The program_id of this LiveTvSeriesTimerInfo.  # noqa: E501
        :type: str
        """

        self._program_id = program_id

    @property
    def name(self):
        """Gets the name of this LiveTvSeriesTimerInfo.  # noqa: E501

        Name of the recording.  # noqa: E501

        :return: The name of this LiveTvSeriesTimerInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this LiveTvSeriesTimerInfo.

        Name of the recording.  # noqa: E501

        :param name: The name of this LiveTvSeriesTimerInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def service_name(self):
        """Gets the service_name of this LiveTvSeriesTimerInfo.  # noqa: E501


        :return: The service_name of this LiveTvSeriesTimerInfo.  # noqa: E501
        :rtype: str
        """
        return self._service_name

    @service_name.setter
    def service_name(self, service_name):
        """Sets the service_name of this LiveTvSeriesTimerInfo.


        :param service_name: The service_name of this LiveTvSeriesTimerInfo.  # noqa: E501
        :type: str
        """

        self._service_name = service_name

    @property
    def overview(self):
        """Gets the overview of this LiveTvSeriesTimerInfo.  # noqa: E501

        Description of the recording.  # noqa: E501

        :return: The overview of this LiveTvSeriesTimerInfo.  # noqa: E501
        :rtype: str
        """
        return self._overview

    @overview.setter
    def overview(self, overview):
        """Sets the overview of this LiveTvSeriesTimerInfo.

        Description of the recording.  # noqa: E501

        :param overview: The overview of this LiveTvSeriesTimerInfo.  # noqa: E501
        :type: str
        """

        self._overview = overview

    @property
    def start_date(self):
        """Gets the start_date of this LiveTvSeriesTimerInfo.  # noqa: E501

        The start date of the recording, in UTC.  # noqa: E501

        :return: The start_date of this LiveTvSeriesTimerInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this LiveTvSeriesTimerInfo.

        The start date of the recording, in UTC.  # noqa: E501

        :param start_date: The start_date of this LiveTvSeriesTimerInfo.  # noqa: E501
        :type: datetime
        """

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this LiveTvSeriesTimerInfo.  # noqa: E501

        The end date of the recording, in UTC.  # noqa: E501

        :return: The end_date of this LiveTvSeriesTimerInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this LiveTvSeriesTimerInfo.

        The end date of the recording, in UTC.  # noqa: E501

        :param end_date: The end_date of this LiveTvSeriesTimerInfo.  # noqa: E501
        :type: datetime
        """

        self._end_date = end_date

    @property
    def record_any_time(self):
        """Gets the record_any_time of this LiveTvSeriesTimerInfo.  # noqa: E501

        A value indicating whether \\[record any time\\].  # noqa: E501

        :return: The record_any_time of this LiveTvSeriesTimerInfo.  # noqa: E501
        :rtype: bool
        """
        return self._record_any_time

    @record_any_time.setter
    def record_any_time(self, record_any_time):
        """Sets the record_any_time of this LiveTvSeriesTimerInfo.

        A value indicating whether \\[record any time\\].  # noqa: E501

        :param record_any_time: The record_any_time of this LiveTvSeriesTimerInfo.  # noqa: E501
        :type: bool
        """

        self._record_any_time = record_any_time

    @property
    def keep_up_to(self):
        """Gets the keep_up_to of this LiveTvSeriesTimerInfo.  # noqa: E501


        :return: The keep_up_to of this LiveTvSeriesTimerInfo.  # noqa: E501
        :rtype: int
        """
        return self._keep_up_to

    @keep_up_to.setter
    def keep_up_to(self, keep_up_to):
        """Sets the keep_up_to of this LiveTvSeriesTimerInfo.


        :param keep_up_to: The keep_up_to of this LiveTvSeriesTimerInfo.  # noqa: E501
        :type: int
        """

        self._keep_up_to = keep_up_to

    @property
    def keep_until(self):
        """Gets the keep_until of this LiveTvSeriesTimerInfo.  # noqa: E501


        :return: The keep_until of this LiveTvSeriesTimerInfo.  # noqa: E501
        :rtype: LiveTvKeepUntil
        """
        return self._keep_until

    @keep_until.setter
    def keep_until(self, keep_until):
        """Sets the keep_until of this LiveTvSeriesTimerInfo.


        :param keep_until: The keep_until of this LiveTvSeriesTimerInfo.  # noqa: E501
        :type: LiveTvKeepUntil
        """

        self._keep_until = keep_until

    @property
    def skip_episodes_in_library(self):
        """Gets the skip_episodes_in_library of this LiveTvSeriesTimerInfo.  # noqa: E501


        :return: The skip_episodes_in_library of this LiveTvSeriesTimerInfo.  # noqa: E501
        :rtype: bool
        """
        return self._skip_episodes_in_library

    @skip_episodes_in_library.setter
    def skip_episodes_in_library(self, skip_episodes_in_library):
        """Sets the skip_episodes_in_library of this LiveTvSeriesTimerInfo.


        :param skip_episodes_in_library: The skip_episodes_in_library of this LiveTvSeriesTimerInfo.  # noqa: E501
        :type: bool
        """

        self._skip_episodes_in_library = skip_episodes_in_library

    @property
    def match_existing_items_with_any_library(self):
        """Gets the match_existing_items_with_any_library of this LiveTvSeriesTimerInfo.  # noqa: E501


        :return: The match_existing_items_with_any_library of this LiveTvSeriesTimerInfo.  # noqa: E501
        :rtype: bool
        """
        return self._match_existing_items_with_any_library

    @match_existing_items_with_any_library.setter
    def match_existing_items_with_any_library(self, match_existing_items_with_any_library):
        """Sets the match_existing_items_with_any_library of this LiveTvSeriesTimerInfo.


        :param match_existing_items_with_any_library: The match_existing_items_with_any_library of this LiveTvSeriesTimerInfo.  # noqa: E501
        :type: bool
        """

        self._match_existing_items_with_any_library = match_existing_items_with_any_library

    @property
    def record_new_only(self):
        """Gets the record_new_only of this LiveTvSeriesTimerInfo.  # noqa: E501

        A value indicating whether \\[record new only\\].  # noqa: E501

        :return: The record_new_only of this LiveTvSeriesTimerInfo.  # noqa: E501
        :rtype: bool
        """
        return self._record_new_only

    @record_new_only.setter
    def record_new_only(self, record_new_only):
        """Sets the record_new_only of this LiveTvSeriesTimerInfo.

        A value indicating whether \\[record new only\\].  # noqa: E501

        :param record_new_only: The record_new_only of this LiveTvSeriesTimerInfo.  # noqa: E501
        :type: bool
        """

        self._record_new_only = record_new_only

    @property
    def days(self):
        """Gets the days of this LiveTvSeriesTimerInfo.  # noqa: E501

        The days.  # noqa: E501

        :return: The days of this LiveTvSeriesTimerInfo.  # noqa: E501
        :rtype: list[DayOfWeek]
        """
        return self._days

    @days.setter
    def days(self, days):
        """Sets the days of this LiveTvSeriesTimerInfo.

        The days.  # noqa: E501

        :param days: The days of this LiveTvSeriesTimerInfo.  # noqa: E501
        :type: list[DayOfWeek]
        """

        self._days = days

    @property
    def priority(self):
        """Gets the priority of this LiveTvSeriesTimerInfo.  # noqa: E501

        The priority.  # noqa: E501

        :return: The priority of this LiveTvSeriesTimerInfo.  # noqa: E501
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """Sets the priority of this LiveTvSeriesTimerInfo.

        The priority.  # noqa: E501

        :param priority: The priority of this LiveTvSeriesTimerInfo.  # noqa: E501
        :type: int
        """

        self._priority = priority

    @property
    def pre_padding_seconds(self):
        """Gets the pre_padding_seconds of this LiveTvSeriesTimerInfo.  # noqa: E501

        The pre padding seconds.  # noqa: E501

        :return: The pre_padding_seconds of this LiveTvSeriesTimerInfo.  # noqa: E501
        :rtype: int
        """
        return self._pre_padding_seconds

    @pre_padding_seconds.setter
    def pre_padding_seconds(self, pre_padding_seconds):
        """Sets the pre_padding_seconds of this LiveTvSeriesTimerInfo.

        The pre padding seconds.  # noqa: E501

        :param pre_padding_seconds: The pre_padding_seconds of this LiveTvSeriesTimerInfo.  # noqa: E501
        :type: int
        """

        self._pre_padding_seconds = pre_padding_seconds

    @property
    def post_padding_seconds(self):
        """Gets the post_padding_seconds of this LiveTvSeriesTimerInfo.  # noqa: E501

        The post padding seconds.  # noqa: E501

        :return: The post_padding_seconds of this LiveTvSeriesTimerInfo.  # noqa: E501
        :rtype: int
        """
        return self._post_padding_seconds

    @post_padding_seconds.setter
    def post_padding_seconds(self, post_padding_seconds):
        """Sets the post_padding_seconds of this LiveTvSeriesTimerInfo.

        The post padding seconds.  # noqa: E501

        :param post_padding_seconds: The post_padding_seconds of this LiveTvSeriesTimerInfo.  # noqa: E501
        :type: int
        """

        self._post_padding_seconds = post_padding_seconds

    @property
    def is_pre_padding_required(self):
        """Gets the is_pre_padding_required of this LiveTvSeriesTimerInfo.  # noqa: E501

        A value indicating whether this instance is pre padding required.  # noqa: E501

        :return: The is_pre_padding_required of this LiveTvSeriesTimerInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_pre_padding_required

    @is_pre_padding_required.setter
    def is_pre_padding_required(self, is_pre_padding_required):
        """Sets the is_pre_padding_required of this LiveTvSeriesTimerInfo.

        A value indicating whether this instance is pre padding required.  # noqa: E501

        :param is_pre_padding_required: The is_pre_padding_required of this LiveTvSeriesTimerInfo.  # noqa: E501
        :type: bool
        """

        self._is_pre_padding_required = is_pre_padding_required

    @property
    def is_post_padding_required(self):
        """Gets the is_post_padding_required of this LiveTvSeriesTimerInfo.  # noqa: E501

        A value indicating whether this instance is post padding required.  # noqa: E501

        :return: The is_post_padding_required of this LiveTvSeriesTimerInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_post_padding_required

    @is_post_padding_required.setter
    def is_post_padding_required(self, is_post_padding_required):
        """Sets the is_post_padding_required of this LiveTvSeriesTimerInfo.

        A value indicating whether this instance is post padding required.  # noqa: E501

        :param is_post_padding_required: The is_post_padding_required of this LiveTvSeriesTimerInfo.  # noqa: E501
        :type: bool
        """

        self._is_post_padding_required = is_post_padding_required

    @property
    def series_id(self):
        """Gets the series_id of this LiveTvSeriesTimerInfo.  # noqa: E501

        The series identifier.  # noqa: E501

        :return: The series_id of this LiveTvSeriesTimerInfo.  # noqa: E501
        :rtype: str
        """
        return self._series_id

    @series_id.setter
    def series_id(self, series_id):
        """Sets the series_id of this LiveTvSeriesTimerInfo.

        The series identifier.  # noqa: E501

        :param series_id: The series_id of this LiveTvSeriesTimerInfo.  # noqa: E501
        :type: str
        """

        self._series_id = series_id

    @property
    def provider_ids(self):
        """Gets the provider_ids of this LiveTvSeriesTimerInfo.  # noqa: E501


        :return: The provider_ids of this LiveTvSeriesTimerInfo.  # noqa: E501
        :rtype: ProviderIdDictionary
        """
        return self._provider_ids

    @provider_ids.setter
    def provider_ids(self, provider_ids):
        """Sets the provider_ids of this LiveTvSeriesTimerInfo.


        :param provider_ids: The provider_ids of this LiveTvSeriesTimerInfo.  # noqa: E501
        :type: ProviderIdDictionary
        """

        self._provider_ids = provider_ids

    @property
    def max_recording_seconds(self):
        """Gets the max_recording_seconds of this LiveTvSeriesTimerInfo.  # noqa: E501


        :return: The max_recording_seconds of this LiveTvSeriesTimerInfo.  # noqa: E501
        :rtype: int
        """
        return self._max_recording_seconds

    @max_recording_seconds.setter
    def max_recording_seconds(self, max_recording_seconds):
        """Sets the max_recording_seconds of this LiveTvSeriesTimerInfo.


        :param max_recording_seconds: The max_recording_seconds of this LiveTvSeriesTimerInfo.  # noqa: E501
        :type: int
        """

        self._max_recording_seconds = max_recording_seconds

    @property
    def keywords(self):
        """Gets the keywords of this LiveTvSeriesTimerInfo.  # noqa: E501


        :return: The keywords of this LiveTvSeriesTimerInfo.  # noqa: E501
        :rtype: list[LiveTvKeywordInfo]
        """
        return self._keywords

    @keywords.setter
    def keywords(self, keywords):
        """Sets the keywords of this LiveTvSeriesTimerInfo.


        :param keywords: The keywords of this LiveTvSeriesTimerInfo.  # noqa: E501
        :type: list[LiveTvKeywordInfo]
        """

        self._keywords = keywords

    @property
    def timer_type(self):
        """Gets the timer_type of this LiveTvSeriesTimerInfo.  # noqa: E501


        :return: The timer_type of this LiveTvSeriesTimerInfo.  # noqa: E501
        :rtype: LiveTvTimerType
        """
        return self._timer_type

    @timer_type.setter
    def timer_type(self, timer_type):
        """Sets the timer_type of this LiveTvSeriesTimerInfo.


        :param timer_type: The timer_type of this LiveTvSeriesTimerInfo.  # noqa: E501
        :type: LiveTvTimerType
        """

        self._timer_type = timer_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LiveTvSeriesTimerInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LiveTvSeriesTimerInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from emby_client.api_client import ApiClient


class GenericUIApiServiceApi(object):
    """NOTE: This class is auto generated.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_ui_view(self, page_id, client_locale, **kwargs):  # noqa: E501
        """Gets UI view data  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ui_view(page_id, client_locale, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str page_id: Id of the page controller (required)
        :param str client_locale: Locale identifier of the client (required)
        :return: UIViewInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_ui_view_with_http_info(page_id, client_locale, **kwargs)  # noqa: E501
        else:
            (data) = self.get_ui_view_with_http_info(page_id, client_locale, **kwargs)  # noqa: E501
            return data

    def get_ui_view_with_http_info(self, page_id, client_locale, **kwargs):  # noqa: E501
        """Gets UI view data  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ui_view_with_http_info(page_id, client_locale, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str page_id: Id of the page controller (required)
        :param str client_locale: Locale identifier of the client (required)
        :return: UIViewInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_id', 'client_locale']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_ui_view" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'page_id' is set
        if ('page_id' not in params or
                params['page_id'] is None):
            raise ValueError("Missing the required parameter `page_id` when calling `get_ui_view`")  # noqa: E501
        # verify the required parameter 'client_locale' is set
        if ('client_locale' not in params or
                params['client_locale'] is None):
            raise ValueError("Missing the required parameter `client_locale` when calling `get_ui_view`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page_id' in params:
            query_params.append(('PageId', params['page_id']))  # noqa: E501
        if 'client_locale' in params:
            query_params.append(('ClientLocale', params['client_locale']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/UI/View', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UIViewInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_ui_command(self, body, **kwargs):  # noqa: E501
        """Execute a command in the context of tv setup  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_ui_command(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RunUICommand body: RunUICommand (required)
        :return: UIViewInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_ui_command_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.post_ui_command_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def post_ui_command_with_http_info(self, body, **kwargs):  # noqa: E501
        """Execute a command in the context of tv setup  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_ui_command_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RunUICommand body: RunUICommand (required)
        :return: UIViewInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_ui_command" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_ui_command`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/UI/Command', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UIViewInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class ChapterInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'start_position_ticks': 'int',
        'name': 'str',
        'image_tag': 'str',
        'marker_type': 'MarkerType',
        'chapter_index': 'int'
    }

    attribute_map = {
        'start_position_ticks': 'StartPositionTicks',
        'name': 'Name',
        'image_tag': 'ImageTag',
        'marker_type': 'MarkerType',
        'chapter_index': 'ChapterIndex'
    }

    def __init__(self, start_position_ticks=None, name=None, image_tag=None, marker_type=None, chapter_index=None):  # noqa: E501
        """ChapterInfo - a model defined in Swagger"""  # noqa: E501
        self._start_position_ticks = None
        self._name = None
        self._image_tag = None
        self._marker_type = None
        self._chapter_index = None
        self.discriminator = None
        if start_position_ticks is not None:
            self.start_position_ticks = start_position_ticks
        if name is not None:
            self.name = name
        if image_tag is not None:
            self.image_tag = image_tag
        if marker_type is not None:
            self.marker_type = marker_type
        if chapter_index is not None:
            self.chapter_index = chapter_index

    @property
    def start_position_ticks(self):
        """Gets the start_position_ticks of this ChapterInfo.  # noqa: E501

        The start position ticks.  # noqa: E501

        :return: The start_position_ticks of this ChapterInfo.  # noqa: E501
        :rtype: int
        """
        return self._start_position_ticks

    @start_position_ticks.setter
    def start_position_ticks(self, start_position_ticks):
        """Sets the start_position_ticks of this ChapterInfo.

        The start position ticks.  # noqa: E501

        :param start_position_ticks: The start_position_ticks of this ChapterInfo.  # noqa: E501
        :type: int
        """

        self._start_position_ticks = start_position_ticks

    @property
    def name(self):
        """Gets the name of this ChapterInfo.  # noqa: E501

        The name.  # noqa: E501

        :return: The name of this ChapterInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ChapterInfo.

        The name.  # noqa: E501

        :param name: The name of this ChapterInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def image_tag(self):
        """Gets the image_tag of this ChapterInfo.  # noqa: E501


        :return: The image_tag of this ChapterInfo.  # noqa: E501
        :rtype: str
        """
        return self._image_tag

    @image_tag.setter
    def image_tag(self, image_tag):
        """Sets the image_tag of this ChapterInfo.


        :param image_tag: The image_tag of this ChapterInfo.  # noqa: E501
        :type: str
        """

        self._image_tag = image_tag

    @property
    def marker_type(self):
        """Gets the marker_type of this ChapterInfo.  # noqa: E501


        :return: The marker_type of this ChapterInfo.  # noqa: E501
        :rtype: MarkerType
        """
        return self._marker_type

    @marker_type.setter
    def marker_type(self, marker_type):
        """Sets the marker_type of this ChapterInfo.


        :param marker_type: The marker_type of this ChapterInfo.  # noqa: E501
        :type: MarkerType
        """

        self._marker_type = marker_type

    @property
    def chapter_index(self):
        """Gets the chapter_index of this ChapterInfo.  # noqa: E501


        :return: The chapter_index of this ChapterInfo.  # noqa: E501
        :rtype: int
        """
        return self._chapter_index

    @chapter_index.setter
    def chapter_index(self, chapter_index):
        """Sets the chapter_index of this ChapterInfo.


        :param chapter_index: The chapter_index of this ChapterInfo.  # noqa: E501
        :type: int
        """

        self._chapter_index = chapter_index

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ChapterInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChapterInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from emby_client.api_client import ApiClient


class PackageServiceApi(object):
    """NOTE: This class is auto generated.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def delete_packages_installing_by_id(self, id, **kwargs):  # noqa: E501
        """Cancels a package installation  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_packages_installing_by_id(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Installation Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_packages_installing_by_id_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_packages_installing_by_id_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def delete_packages_installing_by_id_with_http_info(self, id, **kwargs):  # noqa: E501
        """Cancels a package installation  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_packages_installing_by_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Installation Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_packages_installing_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `delete_packages_installing_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Packages/Installing/{Id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_packages(self, **kwargs):  # noqa: E501
        """Gets available packages  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_packages(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str package_type: Optional package type filter (System/UserInstalled)
        :param str target_systems: Optional. Filter by target system type. Allows multiple, comma delimited.
        :param bool is_premium: Optional. Filter by premium status
        :param bool is_adult: Optional. Filter by package that contain adult content.
        :return: list[PackageInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_packages_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_packages_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_packages_with_http_info(self, **kwargs):  # noqa: E501
        """Gets available packages  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_packages_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str package_type: Optional package type filter (System/UserInstalled)
        :param str target_systems: Optional. Filter by target system type. Allows multiple, comma delimited.
        :param bool is_premium: Optional. Filter by premium status
        :param bool is_adult: Optional. Filter by package that contain adult content.
        :return: list[PackageInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['package_type', 'target_systems', 'is_premium', 'is_adult']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_packages" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'package_type' in params:
            query_params.append(('PackageType', params['package_type']))  # noqa: E501
        if 'target_systems' in params:
            query_params.append(('TargetSystems', params['target_systems']))  # noqa: E501
        if 'is_premium' in params:
            query_params.append(('IsPremium', params['is_premium']))  # noqa: E501
        if 'is_adult' in params:
            query_params.append(('IsAdult', params['is_adult']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Packages', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PackageInfo]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_packages_by_name(self, name, **kwargs):  # noqa: E501
        """Gets a package, by name or assembly guid  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_packages_by_name(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: The name of the package (required)
        :param str assembly_guid: The guid of the associated assembly
        :return: PackageInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_packages_by_name_with_http_info(name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_packages_by_name_with_http_info(name, **kwargs)  # noqa: E501
            return data

    def get_packages_by_name_with_http_info(self, name, **kwargs):  # noqa: E501
        """Gets a package, by name or assembly guid  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_packages_by_name_with_http_info(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: The name of the package (required)
        :param str assembly_guid: The guid of the associated assembly
        :return: PackageInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name', 'assembly_guid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_packages_by_name" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params or
                params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `get_packages_by_name`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['Name'] = params['name']  # noqa: E501

        query_params = []
        if 'assembly_guid' in params:
            query_params.append(('AssemblyGuid', params['assembly_guid']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Packages/{Name}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PackageInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_packages_updates(self, package_type, **kwargs):  # noqa: E501
        """Gets available package updates for currently installed packages  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_packages_updates(package_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str package_type: Package type filter (System/UserInstalled) (required)
        :return: list[PackageVersionInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_packages_updates_with_http_info(package_type, **kwargs)  # noqa: E501
        else:
            (data) = self.get_packages_updates_with_http_info(package_type, **kwargs)  # noqa: E501
            return data

    def get_packages_updates_with_http_info(self, package_type, **kwargs):  # noqa: E501
        """Gets available package updates for currently installed packages  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_packages_updates_with_http_info(package_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str package_type: Package type filter (System/UserInstalled) (required)
        :return: list[PackageVersionInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['package_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_packages_updates" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'package_type' is set
        if ('package_type' not in params or
                params['package_type'] is None):
            raise ValueError("Missing the required parameter `package_type` when calling `get_packages_updates`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'package_type' in params:
            query_params.append(('PackageType', params['package_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Packages/Updates', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PackageVersionInfo]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_packages_installed_by_name(self, name, **kwargs):  # noqa: E501
        """Installs a package  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_packages_installed_by_name(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: Package name (required)
        :param str assembly_guid: Guid of the associated assembly
        :param str version: Optional version. Defaults to latest version.
        :param PackageVersionClass update_class: Optional update class (Dev, Beta, Release). Defaults to Release.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_packages_installed_by_name_with_http_info(name, **kwargs)  # noqa: E501
        else:
            (data) = self.post_packages_installed_by_name_with_http_info(name, **kwargs)  # noqa: E501
            return data

    def post_packages_installed_by_name_with_http_info(self, name, **kwargs):  # noqa: E501
        """Installs a package  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_packages_installed_by_name_with_http_info(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: Package name (required)
        :param str assembly_guid: Guid of the associated assembly
        :param str version: Optional version. Defaults to latest version.
        :param PackageVersionClass update_class: Optional update class (Dev, Beta, Release). Defaults to Release.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name', 'assembly_guid', 'version', 'update_class']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_packages_installed_by_name" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params or
                params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `post_packages_installed_by_name`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['Name'] = params['name']  # noqa: E501

        query_params = []
        if 'assembly_guid' in params:
            query_params.append(('AssemblyGuid', params['assembly_guid']))  # noqa: E501
        if 'version' in params:
            query_params.append(('Version', params['version']))  # noqa: E501
        if 'update_class' in params:
            query_params.append(('UpdateClass', params['update_class']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Packages/Installed/{Name}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_packages_installing_by_id_delete(self, id, **kwargs):  # noqa: E501
        """Cancels a package installation  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_packages_installing_by_id_delete(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Installation Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_packages_installing_by_id_delete_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_packages_installing_by_id_delete_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def post_packages_installing_by_id_delete_with_http_info(self, id, **kwargs):  # noqa: E501
        """Cancels a package installation  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_packages_installing_by_id_delete_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Installation Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_packages_installing_by_id_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_packages_installing_by_id_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Packages/Installing/{Id}/Delete', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class BitRate(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bps': 'int',
        'kbps': 'float',
        'mbps': 'float'
    }

    attribute_map = {
        'bps': 'bps',
        'kbps': 'kbps',
        'mbps': 'Mbps'
    }

    def __init__(self, bps=None, kbps=None, mbps=None):  # noqa: E501
        """BitRate - a model defined in Swagger"""  # noqa: E501
        self._bps = None
        self._kbps = None
        self._mbps = None
        self.discriminator = None
        if bps is not None:
            self.bps = bps
        if kbps is not None:
            self.kbps = kbps
        if mbps is not None:
            self.mbps = mbps

    @property
    def bps(self):
        """Gets the bps of this BitRate.  # noqa: E501


        :return: The bps of this BitRate.  # noqa: E501
        :rtype: int
        """
        return self._bps

    @bps.setter
    def bps(self, bps):
        """Sets the bps of this BitRate.


        :param bps: The bps of this BitRate.  # noqa: E501
        :type: int
        """

        self._bps = bps

    @property
    def kbps(self):
        """Gets the kbps of this BitRate.  # noqa: E501


        :return: The kbps of this BitRate.  # noqa: E501
        :rtype: float
        """
        return self._kbps

    @kbps.setter
    def kbps(self, kbps):
        """Sets the kbps of this BitRate.


        :param kbps: The kbps of this BitRate.  # noqa: E501
        :type: float
        """

        self._kbps = kbps

    @property
    def mbps(self):
        """Gets the mbps of this BitRate.  # noqa: E501


        :return: The mbps of this BitRate.  # noqa: E501
        :rtype: float
        """
        return self._mbps

    @mbps.setter
    def mbps(self, mbps):
        """Sets the mbps of this BitRate.


        :param mbps: The mbps of this BitRate.  # noqa: E501
        :type: float
        """

        self._mbps = mbps

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BitRate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BitRate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class SyncJob(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'target_id': 'str',
        'internal_target_id': 'int',
        'target_name': 'str',
        'quality': 'str',
        'bitrate': 'int',
        'container': 'str',
        'video_codec': 'str',
        'audio_codec': 'str',
        'profile': 'str',
        'category': 'SyncCategory',
        'parent_id': 'int',
        'progress': 'float',
        'name': 'str',
        'status': 'SyncJobStatus',
        'user_id': 'int',
        'unwatched_only': 'bool',
        'sync_new_content': 'bool',
        'item_limit': 'int',
        'requested_item_ids': 'list[int]',
        'item_id': 'int',
        'date_created': 'datetime',
        'date_last_modified': 'datetime',
        'item_count': 'int',
        'parent_name': 'str',
        'primary_image_item_id': 'str',
        'primary_image_tag': 'str'
    }

    attribute_map = {
        'id': 'Id',
        'target_id': 'TargetId',
        'internal_target_id': 'InternalTargetId',
        'target_name': 'TargetName',
        'quality': 'Quality',
        'bitrate': 'Bitrate',
        'container': 'Container',
        'video_codec': 'VideoCodec',
        'audio_codec': 'AudioCodec',
        'profile': 'Profile',
        'category': 'Category',
        'parent_id': 'ParentId',
        'progress': 'Progress',
        'name': 'Name',
        'status': 'Status',
        'user_id': 'UserId',
        'unwatched_only': 'UnwatchedOnly',
        'sync_new_content': 'SyncNewContent',
        'item_limit': 'ItemLimit',
        'requested_item_ids': 'RequestedItemIds',
        'item_id': 'ItemId',
        'date_created': 'DateCreated',
        'date_last_modified': 'DateLastModified',
        'item_count': 'ItemCount',
        'parent_name': 'ParentName',
        'primary_image_item_id': 'PrimaryImageItemId',
        'primary_image_tag': 'PrimaryImageTag'
    }

    def __init__(self, id=None, target_id=None, internal_target_id=None, target_name=None, quality=None, bitrate=None, container=None, video_codec=None, audio_codec=None, profile=None, category=None, parent_id=None, progress=None, name=None, status=None, user_id=None, unwatched_only=None, sync_new_content=None, item_limit=None, requested_item_ids=None, item_id=None, date_created=None, date_last_modified=None, item_count=None, parent_name=None, primary_image_item_id=None, primary_image_tag=None):  # noqa: E501
        """SyncJob - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._target_id = None
        self._internal_target_id = None
        self._target_name = None
        self._quality = None
        self._bitrate = None
        self._container = None
        self._video_codec = None
        self._audio_codec = None
        self._profile = None
        self._category = None
        self._parent_id = None
        self._progress = None
        self._name = None
        self._status = None
        self._user_id = None
        self._unwatched_only = None
        self._sync_new_content = None
        self._item_limit = None
        self._requested_item_ids = None
        self._item_id = None
        self._date_created = None
        self._date_last_modified = None
        self._item_count = None
        self._parent_name = None
        self._primary_image_item_id = None
        self._primary_image_tag = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if target_id is not None:
            self.target_id = target_id
        if internal_target_id is not None:
            self.internal_target_id = internal_target_id
        if target_name is not None:
            self.target_name = target_name
        if quality is not None:
            self.quality = quality
        if bitrate is not None:
            self.bitrate = bitrate
        if container is not None:
            self.container = container
        if video_codec is not None:
            self.video_codec = video_codec
        if audio_codec is not None:
            self.audio_codec = audio_codec
        if profile is not None:
            self.profile = profile
        if category is not None:
            self.category = category
        if parent_id is not None:
            self.parent_id = parent_id
        if progress is not None:
            self.progress = progress
        if name is not None:
            self.name = name
        if status is not None:
            self.status = status
        if user_id is not None:
            self.user_id = user_id
        if unwatched_only is not None:
            self.unwatched_only = unwatched_only
        if sync_new_content is not None:
            self.sync_new_content = sync_new_content
        if item_limit is not None:
            self.item_limit = item_limit
        if requested_item_ids is not None:
            self.requested_item_ids = requested_item_ids
        if item_id is not None:
            self.item_id = item_id
        if date_created is not None:
            self.date_created = date_created
        if date_last_modified is not None:
            self.date_last_modified = date_last_modified
        if item_count is not None:
            self.item_count = item_count
        if parent_name is not None:
            self.parent_name = parent_name
        if primary_image_item_id is not None:
            self.primary_image_item_id = primary_image_item_id
        if primary_image_tag is not None:
            self.primary_image_tag = primary_image_tag

    @property
    def id(self):
        """Gets the id of this SyncJob.  # noqa: E501

        The identifier.  # noqa: E501

        :return: The id of this SyncJob.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SyncJob.

        The identifier.  # noqa: E501

        :param id: The id of this SyncJob.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def target_id(self):
        """Gets the target_id of this SyncJob.  # noqa: E501

        The device identifier.  # noqa: E501

        :return: The target_id of this SyncJob.  # noqa: E501
        :rtype: str
        """
        return self._target_id

    @target_id.setter
    def target_id(self, target_id):
        """Sets the target_id of this SyncJob.

        The device identifier.  # noqa: E501

        :param target_id: The target_id of this SyncJob.  # noqa: E501
        :type: str
        """

        self._target_id = target_id

    @property
    def internal_target_id(self):
        """Gets the internal_target_id of this SyncJob.  # noqa: E501


        :return: The internal_target_id of this SyncJob.  # noqa: E501
        :rtype: int
        """
        return self._internal_target_id

    @internal_target_id.setter
    def internal_target_id(self, internal_target_id):
        """Sets the internal_target_id of this SyncJob.


        :param internal_target_id: The internal_target_id of this SyncJob.  # noqa: E501
        :type: int
        """

        self._internal_target_id = internal_target_id

    @property
    def target_name(self):
        """Gets the target_name of this SyncJob.  # noqa: E501

        The name of the target.  # noqa: E501

        :return: The target_name of this SyncJob.  # noqa: E501
        :rtype: str
        """
        return self._target_name

    @target_name.setter
    def target_name(self, target_name):
        """Sets the target_name of this SyncJob.

        The name of the target.  # noqa: E501

        :param target_name: The target_name of this SyncJob.  # noqa: E501
        :type: str
        """

        self._target_name = target_name

    @property
    def quality(self):
        """Gets the quality of this SyncJob.  # noqa: E501

        The quality.  # noqa: E501

        :return: The quality of this SyncJob.  # noqa: E501
        :rtype: str
        """
        return self._quality

    @quality.setter
    def quality(self, quality):
        """Sets the quality of this SyncJob.

        The quality.  # noqa: E501

        :param quality: The quality of this SyncJob.  # noqa: E501
        :type: str
        """

        self._quality = quality

    @property
    def bitrate(self):
        """Gets the bitrate of this SyncJob.  # noqa: E501

        The bitrate.  # noqa: E501

        :return: The bitrate of this SyncJob.  # noqa: E501
        :rtype: int
        """
        return self._bitrate

    @bitrate.setter
    def bitrate(self, bitrate):
        """Sets the bitrate of this SyncJob.

        The bitrate.  # noqa: E501

        :param bitrate: The bitrate of this SyncJob.  # noqa: E501
        :type: int
        """

        self._bitrate = bitrate

    @property
    def container(self):
        """Gets the container of this SyncJob.  # noqa: E501


        :return: The container of this SyncJob.  # noqa: E501
        :rtype: str
        """
        return self._container

    @container.setter
    def container(self, container):
        """Sets the container of this SyncJob.


        :param container: The container of this SyncJob.  # noqa: E501
        :type: str
        """

        self._container = container

    @property
    def video_codec(self):
        """Gets the video_codec of this SyncJob.  # noqa: E501


        :return: The video_codec of this SyncJob.  # noqa: E501
        :rtype: str
        """
        return self._video_codec

    @video_codec.setter
    def video_codec(self, video_codec):
        """Sets the video_codec of this SyncJob.


        :param video_codec: The video_codec of this SyncJob.  # noqa: E501
        :type: str
        """

        self._video_codec = video_codec

    @property
    def audio_codec(self):
        """Gets the audio_codec of this SyncJob.  # noqa: E501


        :return: The audio_codec of this SyncJob.  # noqa: E501
        :rtype: str
        """
        return self._audio_codec

    @audio_codec.setter
    def audio_codec(self, audio_codec):
        """Sets the audio_codec of this SyncJob.


        :param audio_codec: The audio_codec of this SyncJob.  # noqa: E501
        :type: str
        """

        self._audio_codec = audio_codec

    @property
    def profile(self):
        """Gets the profile of this SyncJob.  # noqa: E501

        The profile.  # noqa: E501

        :return: The profile of this SyncJob.  # noqa: E501
        :rtype: str
        """
        return self._profile

    @profile.setter
    def profile(self, profile):
        """Sets the profile of this SyncJob.

        The profile.  # noqa: E501

        :param profile: The profile of this SyncJob.  # noqa: E501
        :type: str
        """

        self._profile = profile

    @property
    def category(self):
        """Gets the category of this SyncJob.  # noqa: E501


        :return: The category of this SyncJob.  # noqa: E501
        :rtype: SyncCategory
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this SyncJob.


        :param category: The category of this SyncJob.  # noqa: E501
        :type: SyncCategory
        """

        self._category = category

    @property
    def parent_id(self):
        """Gets the parent_id of this SyncJob.  # noqa: E501

        The parent identifier.  # noqa: E501

        :return: The parent_id of this SyncJob.  # noqa: E501
        :rtype: int
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """Sets the parent_id of this SyncJob.

        The parent identifier.  # noqa: E501

        :param parent_id: The parent_id of this SyncJob.  # noqa: E501
        :type: int
        """

        self._parent_id = parent_id

    @property
    def progress(self):
        """Gets the progress of this SyncJob.  # noqa: E501

        The current progress.  # noqa: E501

        :return: The progress of this SyncJob.  # noqa: E501
        :rtype: float
        """
        return self._progress

    @progress.setter
    def progress(self, progress):
        """Sets the progress of this SyncJob.

        The current progress.  # noqa: E501

        :param progress: The progress of this SyncJob.  # noqa: E501
        :type: float
        """

        self._progress = progress

    @property
    def name(self):
        """Gets the name of this SyncJob.  # noqa: E501

        The name.  # noqa: E501

        :return: The name of this SyncJob.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SyncJob.

        The name.  # noqa: E501

        :param name: The name of this SyncJob.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def status(self):
        """Gets the status of this SyncJob.  # noqa: E501


        :return: The status of this SyncJob.  # noqa: E501
        :rtype: SyncJobStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this SyncJob.


        :param status: The status of this SyncJob.  # noqa: E501
        :type: SyncJobStatus
        """

        self._status = status

    @property
    def user_id(self):
        """Gets the user_id of this SyncJob.  # noqa: E501

        The user identifier.  # noqa: E501

        :return: The user_id of this SyncJob.  # noqa: E501
        :rtype: int
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this SyncJob.

        The user identifier.  # noqa: E501

        :param user_id: The user_id of this SyncJob.  # noqa: E501
        :type: int
        """

        self._user_id = user_id

    @property
    def unwatched_only(self):
        """Gets the unwatched_only of this SyncJob.  # noqa: E501

        A value indicating whether \\[unwatched only\\].  # noqa: E501

        :return: The unwatched_only of this SyncJob.  # noqa: E501
        :rtype: bool
        """
        return self._unwatched_only

    @unwatched_only.setter
    def unwatched_only(self, unwatched_only):
        """Sets the unwatched_only of this SyncJob.

        A value indicating whether \\[unwatched only\\].  # noqa: E501

        :param unwatched_only: The unwatched_only of this SyncJob.  # noqa: E501
        :type: bool
        """

        self._unwatched_only = unwatched_only

    @property
    def sync_new_content(self):
        """Gets the sync_new_content of this SyncJob.  # noqa: E501

        A value indicating whether \\[synchronize new content\\].  # noqa: E501

        :return: The sync_new_content of this SyncJob.  # noqa: E501
        :rtype: bool
        """
        return self._sync_new_content

    @sync_new_content.setter
    def sync_new_content(self, sync_new_content):
        """Sets the sync_new_content of this SyncJob.

        A value indicating whether \\[synchronize new content\\].  # noqa: E501

        :param sync_new_content: The sync_new_content of this SyncJob.  # noqa: E501
        :type: bool
        """

        self._sync_new_content = sync_new_content

    @property
    def item_limit(self):
        """Gets the item_limit of this SyncJob.  # noqa: E501

        The item limit.  # noqa: E501

        :return: The item_limit of this SyncJob.  # noqa: E501
        :rtype: int
        """
        return self._item_limit

    @item_limit.setter
    def item_limit(self, item_limit):
        """Sets the item_limit of this SyncJob.

        The item limit.  # noqa: E501

        :param item_limit: The item_limit of this SyncJob.  # noqa: E501
        :type: int
        """

        self._item_limit = item_limit

    @property
    def requested_item_ids(self):
        """Gets the requested_item_ids of this SyncJob.  # noqa: E501

        The requested item ids.  # noqa: E501

        :return: The requested_item_ids of this SyncJob.  # noqa: E501
        :rtype: list[int]
        """
        return self._requested_item_ids

    @requested_item_ids.setter
    def requested_item_ids(self, requested_item_ids):
        """Sets the requested_item_ids of this SyncJob.

        The requested item ids.  # noqa: E501

        :param requested_item_ids: The requested_item_ids of this SyncJob.  # noqa: E501
        :type: list[int]
        """

        self._requested_item_ids = requested_item_ids

    @property
    def item_id(self):
        """Gets the item_id of this SyncJob.  # noqa: E501


        :return: The item_id of this SyncJob.  # noqa: E501
        :rtype: int
        """
        return self._item_id

    @item_id.setter
    def item_id(self, item_id):
        """Sets the item_id of this SyncJob.


        :param item_id: The item_id of this SyncJob.  # noqa: E501
        :type: int
        """

        self._item_id = item_id

    @property
    def date_created(self):
        """Gets the date_created of this SyncJob.  # noqa: E501

        The date created.  # noqa: E501

        :return: The date_created of this SyncJob.  # noqa: E501
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this SyncJob.

        The date created.  # noqa: E501

        :param date_created: The date_created of this SyncJob.  # noqa: E501
        :type: datetime
        """

        self._date_created = date_created

    @property
    def date_last_modified(self):
        """Gets the date_last_modified of this SyncJob.  # noqa: E501

        The date last modified.  # noqa: E501

        :return: The date_last_modified of this SyncJob.  # noqa: E501
        :rtype: datetime
        """
        return self._date_last_modified

    @date_last_modified.setter
    def date_last_modified(self, date_last_modified):
        """Sets the date_last_modified of this SyncJob.

        The date last modified.  # noqa: E501

        :param date_last_modified: The date_last_modified of this SyncJob.  # noqa: E501
        :type: datetime
        """

        self._date_last_modified = date_last_modified

    @property
    def item_count(self):
        """Gets the item_count of this SyncJob.  # noqa: E501

        The item count.  # noqa: E501

        :return: The item_count of this SyncJob.  # noqa: E501
        :rtype: int
        """
        return self._item_count

    @item_count.setter
    def item_count(self, item_count):
        """Sets the item_count of this SyncJob.

        The item count.  # noqa: E501

        :param item_count: The item_count of this SyncJob.  # noqa: E501
        :type: int
        """

        self._item_count = item_count

    @property
    def parent_name(self):
        """Gets the parent_name of this SyncJob.  # noqa: E501


        :return: The parent_name of this SyncJob.  # noqa: E501
        :rtype: str
        """
        return self._parent_name

    @parent_name.setter
    def parent_name(self, parent_name):
        """Sets the parent_name of this SyncJob.


        :param parent_name: The parent_name of this SyncJob.  # noqa: E501
        :type: str
        """

        self._parent_name = parent_name

    @property
    def primary_image_item_id(self):
        """Gets the primary_image_item_id of this SyncJob.  # noqa: E501


        :return: The primary_image_item_id of this SyncJob.  # noqa: E501
        :rtype: str
        """
        return self._primary_image_item_id

    @primary_image_item_id.setter
    def primary_image_item_id(self, primary_image_item_id):
        """Sets the primary_image_item_id of this SyncJob.


        :param primary_image_item_id: The primary_image_item_id of this SyncJob.  # noqa: E501
        :type: str
        """

        self._primary_image_item_id = primary_image_item_id

    @property
    def primary_image_tag(self):
        """Gets the primary_image_tag of this SyncJob.  # noqa: E501


        :return: The primary_image_tag of this SyncJob.  # noqa: E501
        :rtype: str
        """
        return self._primary_image_tag

    @primary_image_tag.setter
    def primary_image_tag(self, primary_image_tag):
        """Sets the primary_image_tag of this SyncJob.


        :param primary_image_tag: The primary_image_tag of this SyncJob.  # noqa: E501
        :type: str
        """

        self._primary_image_tag = primary_image_tag

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SyncJob, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SyncJob):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class MBBackupBackupInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'server_version': 'str',
        'plugin_version': 'str',
        'name': 'str',
        'can_restore': 'bool',
        'is_full_backup': 'bool',
        'date_created': 'datetime',
        'users': 'list[NameIdPair]'
    }

    attribute_map = {
        'server_version': 'ServerVersion',
        'plugin_version': 'PluginVersion',
        'name': 'Name',
        'can_restore': 'CanRestore',
        'is_full_backup': 'IsFullBackup',
        'date_created': 'DateCreated',
        'users': 'Users'
    }

    def __init__(self, server_version=None, plugin_version=None, name=None, can_restore=None, is_full_backup=None, date_created=None, users=None):  # noqa: E501
        """MBBackupBackupInfo - a model defined in Swagger"""  # noqa: E501
        self._server_version = None
        self._plugin_version = None
        self._name = None
        self._can_restore = None
        self._is_full_backup = None
        self._date_created = None
        self._users = None
        self.discriminator = None
        if server_version is not None:
            self.server_version = server_version
        if plugin_version is not None:
            self.plugin_version = plugin_version
        if name is not None:
            self.name = name
        if can_restore is not None:
            self.can_restore = can_restore
        if is_full_backup is not None:
            self.is_full_backup = is_full_backup
        if date_created is not None:
            self.date_created = date_created
        if users is not None:
            self.users = users

    @property
    def server_version(self):
        """Gets the server_version of this MBBackupBackupInfo.  # noqa: E501


        :return: The server_version of this MBBackupBackupInfo.  # noqa: E501
        :rtype: str
        """
        return self._server_version

    @server_version.setter
    def server_version(self, server_version):
        """Sets the server_version of this MBBackupBackupInfo.


        :param server_version: The server_version of this MBBackupBackupInfo.  # noqa: E501
        :type: str
        """

        self._server_version = server_version

    @property
    def plugin_version(self):
        """Gets the plugin_version of this MBBackupBackupInfo.  # noqa: E501


        :return: The plugin_version of this MBBackupBackupInfo.  # noqa: E501
        :rtype: str
        """
        return self._plugin_version

    @plugin_version.setter
    def plugin_version(self, plugin_version):
        """Sets the plugin_version of this MBBackupBackupInfo.


        :param plugin_version: The plugin_version of this MBBackupBackupInfo.  # noqa: E501
        :type: str
        """

        self._plugin_version = plugin_version

    @property
    def name(self):
        """Gets the name of this MBBackupBackupInfo.  # noqa: E501


        :return: The name of this MBBackupBackupInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this MBBackupBackupInfo.


        :param name: The name of this MBBackupBackupInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def can_restore(self):
        """Gets the can_restore of this MBBackupBackupInfo.  # noqa: E501


        :return: The can_restore of this MBBackupBackupInfo.  # noqa: E501
        :rtype: bool
        """
        return self._can_restore

    @can_restore.setter
    def can_restore(self, can_restore):
        """Sets the can_restore of this MBBackupBackupInfo.


        :param can_restore: The can_restore of this MBBackupBackupInfo.  # noqa: E501
        :type: bool
        """

        self._can_restore = can_restore

    @property
    def is_full_backup(self):
        """Gets the is_full_backup of this MBBackupBackupInfo.  # noqa: E501


        :return: The is_full_backup of this MBBackupBackupInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_full_backup

    @is_full_backup.setter
    def is_full_backup(self, is_full_backup):
        """Sets the is_full_backup of this MBBackupBackupInfo.


        :param is_full_backup: The is_full_backup of this MBBackupBackupInfo.  # noqa: E501
        :type: bool
        """

        self._is_full_backup = is_full_backup

    @property
    def date_created(self):
        """Gets the date_created of this MBBackupBackupInfo.  # noqa: E501


        :return: The date_created of this MBBackupBackupInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this MBBackupBackupInfo.


        :param date_created: The date_created of this MBBackupBackupInfo.  # noqa: E501
        :type: datetime
        """

        self._date_created = date_created

    @property
    def users(self):
        """Gets the users of this MBBackupBackupInfo.  # noqa: E501


        :return: The users of this MBBackupBackupInfo.  # noqa: E501
        :rtype: list[NameIdPair]
        """
        return self._users

    @users.setter
    def users(self, users):
        """Sets the users of this MBBackupBackupInfo.


        :param users: The users of this MBBackupBackupInfo.  # noqa: E501
        :type: list[NameIdPair]
        """

        self._users = users

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MBBackupBackupInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MBBackupBackupInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class TypeOptions(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'metadata_fetchers': 'list[str]',
        'metadata_fetcher_order': 'list[str]',
        'image_fetchers': 'list[str]',
        'image_fetcher_order': 'list[str]',
        'image_options': 'list[ImageOption]'
    }

    attribute_map = {
        'type': 'Type',
        'metadata_fetchers': 'MetadataFetchers',
        'metadata_fetcher_order': 'MetadataFetcherOrder',
        'image_fetchers': 'ImageFetchers',
        'image_fetcher_order': 'ImageFetcherOrder',
        'image_options': 'ImageOptions'
    }

    def __init__(self, type=None, metadata_fetchers=None, metadata_fetcher_order=None, image_fetchers=None, image_fetcher_order=None, image_options=None):  # noqa: E501
        """TypeOptions - a model defined in Swagger"""  # noqa: E501
        self._type = None
        self._metadata_fetchers = None
        self._metadata_fetcher_order = None
        self._image_fetchers = None
        self._image_fetcher_order = None
        self._image_options = None
        self.discriminator = None
        if type is not None:
            self.type = type
        if metadata_fetchers is not None:
            self.metadata_fetchers = metadata_fetchers
        if metadata_fetcher_order is not None:
            self.metadata_fetcher_order = metadata_fetcher_order
        if image_fetchers is not None:
            self.image_fetchers = image_fetchers
        if image_fetcher_order is not None:
            self.image_fetcher_order = image_fetcher_order
        if image_options is not None:
            self.image_options = image_options

    @property
    def type(self):
        """Gets the type of this TypeOptions.  # noqa: E501


        :return: The type of this TypeOptions.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this TypeOptions.


        :param type: The type of this TypeOptions.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def metadata_fetchers(self):
        """Gets the metadata_fetchers of this TypeOptions.  # noqa: E501


        :return: The metadata_fetchers of this TypeOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._metadata_fetchers

    @metadata_fetchers.setter
    def metadata_fetchers(self, metadata_fetchers):
        """Sets the metadata_fetchers of this TypeOptions.


        :param metadata_fetchers: The metadata_fetchers of this TypeOptions.  # noqa: E501
        :type: list[str]
        """

        self._metadata_fetchers = metadata_fetchers

    @property
    def metadata_fetcher_order(self):
        """Gets the metadata_fetcher_order of this TypeOptions.  # noqa: E501


        :return: The metadata_fetcher_order of this TypeOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._metadata_fetcher_order

    @metadata_fetcher_order.setter
    def metadata_fetcher_order(self, metadata_fetcher_order):
        """Sets the metadata_fetcher_order of this TypeOptions.


        :param metadata_fetcher_order: The metadata_fetcher_order of this TypeOptions.  # noqa: E501
        :type: list[str]
        """

        self._metadata_fetcher_order = metadata_fetcher_order

    @property
    def image_fetchers(self):
        """Gets the image_fetchers of this TypeOptions.  # noqa: E501


        :return: The image_fetchers of this TypeOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._image_fetchers

    @image_fetchers.setter
    def image_fetchers(self, image_fetchers):
        """Sets the image_fetchers of this TypeOptions.


        :param image_fetchers: The image_fetchers of this TypeOptions.  # noqa: E501
        :type: list[str]
        """

        self._image_fetchers = image_fetchers

    @property
    def image_fetcher_order(self):
        """Gets the image_fetcher_order of this TypeOptions.  # noqa: E501


        :return: The image_fetcher_order of this TypeOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._image_fetcher_order

    @image_fetcher_order.setter
    def image_fetcher_order(self, image_fetcher_order):
        """Sets the image_fetcher_order of this TypeOptions.


        :param image_fetcher_order: The image_fetcher_order of this TypeOptions.  # noqa: E501
        :type: list[str]
        """

        self._image_fetcher_order = image_fetcher_order

    @property
    def image_options(self):
        """Gets the image_options of this TypeOptions.  # noqa: E501


        :return: The image_options of this TypeOptions.  # noqa: E501
        :rtype: list[ImageOption]
        """
        return self._image_options

    @image_options.setter
    def image_options(self, image_options):
        """Sets the image_options of this TypeOptions.


        :param image_options: The image_options of this TypeOptions.  # noqa: E501
        :type: list[ImageOption]
        """

        self._image_options = image_options

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TypeOptions, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TypeOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class RemoteImageInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'provider_name': 'str',
        'url': 'str',
        'thumbnail_url': 'str',
        'height': 'int',
        'width': 'int',
        'community_rating': 'float',
        'vote_count': 'int',
        'language': 'str',
        'display_language': 'str',
        'type': 'ImageType',
        'rating_type': 'RatingType'
    }

    attribute_map = {
        'provider_name': 'ProviderName',
        'url': 'Url',
        'thumbnail_url': 'ThumbnailUrl',
        'height': 'Height',
        'width': 'Width',
        'community_rating': 'CommunityRating',
        'vote_count': 'VoteCount',
        'language': 'Language',
        'display_language': 'DisplayLanguage',
        'type': 'Type',
        'rating_type': 'RatingType'
    }

    def __init__(self, provider_name=None, url=None, thumbnail_url=None, height=None, width=None, community_rating=None, vote_count=None, language=None, display_language=None, type=None, rating_type=None):  # noqa: E501
        """RemoteImageInfo - a model defined in Swagger"""  # noqa: E501
        self._provider_name = None
        self._url = None
        self._thumbnail_url = None
        self._height = None
        self._width = None
        self._community_rating = None
        self._vote_count = None
        self._language = None
        self._display_language = None
        self._type = None
        self._rating_type = None
        self.discriminator = None
        if provider_name is not None:
            self.provider_name = provider_name
        if url is not None:
            self.url = url
        if thumbnail_url is not None:
            self.thumbnail_url = thumbnail_url
        if height is not None:
            self.height = height
        if width is not None:
            self.width = width
        if community_rating is not None:
            self.community_rating = community_rating
        if vote_count is not None:
            self.vote_count = vote_count
        if language is not None:
            self.language = language
        if display_language is not None:
            self.display_language = display_language
        if type is not None:
            self.type = type
        if rating_type is not None:
            self.rating_type = rating_type

    @property
    def provider_name(self):
        """Gets the provider_name of this RemoteImageInfo.  # noqa: E501

        The name of the provider.  # noqa: E501

        :return: The provider_name of this RemoteImageInfo.  # noqa: E501
        :rtype: str
        """
        return self._provider_name

    @provider_name.setter
    def provider_name(self, provider_name):
        """Sets the provider_name of this RemoteImageInfo.

        The name of the provider.  # noqa: E501

        :param provider_name: The provider_name of this RemoteImageInfo.  # noqa: E501
        :type: str
        """

        self._provider_name = provider_name

    @property
    def url(self):
        """Gets the url of this RemoteImageInfo.  # noqa: E501

        The URL.  # noqa: E501

        :return: The url of this RemoteImageInfo.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this RemoteImageInfo.

        The URL.  # noqa: E501

        :param url: The url of this RemoteImageInfo.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def thumbnail_url(self):
        """Gets the thumbnail_url of this RemoteImageInfo.  # noqa: E501

        A url used for previewing a smaller version  # noqa: E501

        :return: The thumbnail_url of this RemoteImageInfo.  # noqa: E501
        :rtype: str
        """
        return self._thumbnail_url

    @thumbnail_url.setter
    def thumbnail_url(self, thumbnail_url):
        """Sets the thumbnail_url of this RemoteImageInfo.

        A url used for previewing a smaller version  # noqa: E501

        :param thumbnail_url: The thumbnail_url of this RemoteImageInfo.  # noqa: E501
        :type: str
        """

        self._thumbnail_url = thumbnail_url

    @property
    def height(self):
        """Gets the height of this RemoteImageInfo.  # noqa: E501

        The height.  # noqa: E501

        :return: The height of this RemoteImageInfo.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this RemoteImageInfo.

        The height.  # noqa: E501

        :param height: The height of this RemoteImageInfo.  # noqa: E501
        :type: int
        """

        self._height = height

    @property
    def width(self):
        """Gets the width of this RemoteImageInfo.  # noqa: E501

        The width.  # noqa: E501

        :return: The width of this RemoteImageInfo.  # noqa: E501
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this RemoteImageInfo.

        The width.  # noqa: E501

        :param width: The width of this RemoteImageInfo.  # noqa: E501
        :type: int
        """

        self._width = width

    @property
    def community_rating(self):
        """Gets the community_rating of this RemoteImageInfo.  # noqa: E501

        The community rating.  # noqa: E501

        :return: The community_rating of this RemoteImageInfo.  # noqa: E501
        :rtype: float
        """
        return self._community_rating

    @community_rating.setter
    def community_rating(self, community_rating):
        """Sets the community_rating of this RemoteImageInfo.

        The community rating.  # noqa: E501

        :param community_rating: The community_rating of this RemoteImageInfo.  # noqa: E501
        :type: float
        """

        self._community_rating = community_rating

    @property
    def vote_count(self):
        """Gets the vote_count of this RemoteImageInfo.  # noqa: E501

        The vote count.  # noqa: E501

        :return: The vote_count of this RemoteImageInfo.  # noqa: E501
        :rtype: int
        """
        return self._vote_count

    @vote_count.setter
    def vote_count(self, vote_count):
        """Sets the vote_count of this RemoteImageInfo.

        The vote count.  # noqa: E501

        :param vote_count: The vote_count of this RemoteImageInfo.  # noqa: E501
        :type: int
        """

        self._vote_count = vote_count

    @property
    def language(self):
        """Gets the language of this RemoteImageInfo.  # noqa: E501

        The language.  # noqa: E501

        :return: The language of this RemoteImageInfo.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this RemoteImageInfo.

        The language.  # noqa: E501

        :param language: The language of this RemoteImageInfo.  # noqa: E501
        :type: str
        """

        self._language = language

    @property
    def display_language(self):
        """Gets the display_language of this RemoteImageInfo.  # noqa: E501


        :return: The display_language of this RemoteImageInfo.  # noqa: E501
        :rtype: str
        """
        return self._display_language

    @display_language.setter
    def display_language(self, display_language):
        """Sets the display_language of this RemoteImageInfo.


        :param display_language: The display_language of this RemoteImageInfo.  # noqa: E501
        :type: str
        """

        self._display_language = display_language

    @property
    def type(self):
        """Gets the type of this RemoteImageInfo.  # noqa: E501


        :return: The type of this RemoteImageInfo.  # noqa: E501
        :rtype: ImageType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this RemoteImageInfo.


        :param type: The type of this RemoteImageInfo.  # noqa: E501
        :type: ImageType
        """

        self._type = type

    @property
    def rating_type(self):
        """Gets the rating_type of this RemoteImageInfo.  # noqa: E501


        :return: The rating_type of this RemoteImageInfo.  # noqa: E501
        :rtype: RatingType
        """
        return self._rating_type

    @rating_type.setter
    def rating_type(self, rating_type):
        """Sets the rating_type of this RemoteImageInfo.


        :param rating_type: The rating_type of this RemoteImageInfo.  # noqa: E501
        :type: RatingType
        """

        self._rating_type = rating_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RemoteImageInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RemoteImageInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class UIViewInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'view_id': 'str',
        'page_id': 'str',
        'caption': 'str',
        'sub_caption': 'str',
        'plugin_id': 'str',
        'view_type': 'EnumsUIViewType',
        'show_dialog_full_screen': 'bool',
        'is_in_sequence': 'bool',
        'redirect_view_url': 'str',
        'edit_object_container': 'GenericEditIEditObjectContainer',
        'commands': 'list[UICommand]',
        'tab_page_infos': 'list[UITabPageInfo]',
        'is_page_change_info': 'bool'
    }

    attribute_map = {
        'view_id': 'ViewId',
        'page_id': 'PageId',
        'caption': 'Caption',
        'sub_caption': 'SubCaption',
        'plugin_id': 'PluginId',
        'view_type': 'ViewType',
        'show_dialog_full_screen': 'ShowDialogFullScreen',
        'is_in_sequence': 'IsInSequence',
        'redirect_view_url': 'RedirectViewUrl',
        'edit_object_container': 'EditObjectContainer',
        'commands': 'Commands',
        'tab_page_infos': 'TabPageInfos',
        'is_page_change_info': 'IsPageChangeInfo'
    }

    def __init__(self, view_id=None, page_id=None, caption=None, sub_caption=None, plugin_id=None, view_type=None, show_dialog_full_screen=None, is_in_sequence=None, redirect_view_url=None, edit_object_container=None, commands=None, tab_page_infos=None, is_page_change_info=None):  # noqa: E501
        """UIViewInfo - a model defined in Swagger"""  # noqa: E501
        self._view_id = None
        self._page_id = None
        self._caption = None
        self._sub_caption = None
        self._plugin_id = None
        self._view_type = None
        self._show_dialog_full_screen = None
        self._is_in_sequence = None
        self._redirect_view_url = None
        self._edit_object_container = None
        self._commands = None
        self._tab_page_infos = None
        self._is_page_change_info = None
        self.discriminator = None
        if view_id is not None:
            self.view_id = view_id
        if page_id is not None:
            self.page_id = page_id
        if caption is not None:
            self.caption = caption
        if sub_caption is not None:
            self.sub_caption = sub_caption
        if plugin_id is not None:
            self.plugin_id = plugin_id
        if view_type is not None:
            self.view_type = view_type
        if show_dialog_full_screen is not None:
            self.show_dialog_full_screen = show_dialog_full_screen
        if is_in_sequence is not None:
            self.is_in_sequence = is_in_sequence
        if redirect_view_url is not None:
            self.redirect_view_url = redirect_view_url
        if edit_object_container is not None:
            self.edit_object_container = edit_object_container
        if commands is not None:
            self.commands = commands
        if tab_page_infos is not None:
            self.tab_page_infos = tab_page_infos
        if is_page_change_info is not None:
            self.is_page_change_info = is_page_change_info

    @property
    def view_id(self):
        """Gets the view_id of this UIViewInfo.  # noqa: E501


        :return: The view_id of this UIViewInfo.  # noqa: E501
        :rtype: str
        """
        return self._view_id

    @view_id.setter
    def view_id(self, view_id):
        """Sets the view_id of this UIViewInfo.


        :param view_id: The view_id of this UIViewInfo.  # noqa: E501
        :type: str
        """

        self._view_id = view_id

    @property
    def page_id(self):
        """Gets the page_id of this UIViewInfo.  # noqa: E501


        :return: The page_id of this UIViewInfo.  # noqa: E501
        :rtype: str
        """
        return self._page_id

    @page_id.setter
    def page_id(self, page_id):
        """Sets the page_id of this UIViewInfo.


        :param page_id: The page_id of this UIViewInfo.  # noqa: E501
        :type: str
        """

        self._page_id = page_id

    @property
    def caption(self):
        """Gets the caption of this UIViewInfo.  # noqa: E501


        :return: The caption of this UIViewInfo.  # noqa: E501
        :rtype: str
        """
        return self._caption

    @caption.setter
    def caption(self, caption):
        """Sets the caption of this UIViewInfo.


        :param caption: The caption of this UIViewInfo.  # noqa: E501
        :type: str
        """

        self._caption = caption

    @property
    def sub_caption(self):
        """Gets the sub_caption of this UIViewInfo.  # noqa: E501


        :return: The sub_caption of this UIViewInfo.  # noqa: E501
        :rtype: str
        """
        return self._sub_caption

    @sub_caption.setter
    def sub_caption(self, sub_caption):
        """Sets the sub_caption of this UIViewInfo.


        :param sub_caption: The sub_caption of this UIViewInfo.  # noqa: E501
        :type: str
        """

        self._sub_caption = sub_caption

    @property
    def plugin_id(self):
        """Gets the plugin_id of this UIViewInfo.  # noqa: E501


        :return: The plugin_id of this UIViewInfo.  # noqa: E501
        :rtype: str
        """
        return self._plugin_id

    @plugin_id.setter
    def plugin_id(self, plugin_id):
        """Sets the plugin_id of this UIViewInfo.


        :param plugin_id: The plugin_id of this UIViewInfo.  # noqa: E501
        :type: str
        """

        self._plugin_id = plugin_id

    @property
    def view_type(self):
        """Gets the view_type of this UIViewInfo.  # noqa: E501


        :return: The view_type of this UIViewInfo.  # noqa: E501
        :rtype: EnumsUIViewType
        """
        return self._view_type

    @view_type.setter
    def view_type(self, view_type):
        """Sets the view_type of this UIViewInfo.


        :param view_type: The view_type of this UIViewInfo.  # noqa: E501
        :type: EnumsUIViewType
        """

        self._view_type = view_type

    @property
    def show_dialog_full_screen(self):
        """Gets the show_dialog_full_screen of this UIViewInfo.  # noqa: E501


        :return: The show_dialog_full_screen of this UIViewInfo.  # noqa: E501
        :rtype: bool
        """
        return self._show_dialog_full_screen

    @show_dialog_full_screen.setter
    def show_dialog_full_screen(self, show_dialog_full_screen):
        """Sets the show_dialog_full_screen of this UIViewInfo.


        :param show_dialog_full_screen: The show_dialog_full_screen of this UIViewInfo.  # noqa: E501
        :type: bool
        """

        self._show_dialog_full_screen = show_dialog_full_screen

    @property
    def is_in_sequence(self):
        """Gets the is_in_sequence of this UIViewInfo.  # noqa: E501


        :return: The is_in_sequence of this UIViewInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_in_sequence

    @is_in_sequence.setter
    def is_in_sequence(self, is_in_sequence):
        """Sets the is_in_sequence of this UIViewInfo.


        :param is_in_sequence: The is_in_sequence of this UIViewInfo.  # noqa: E501
        :type: bool
        """

        self._is_in_sequence = is_in_sequence

    @property
    def redirect_view_url(self):
        """Gets the redirect_view_url of this UIViewInfo.  # noqa: E501


        :return: The redirect_view_url of this UIViewInfo.  # noqa: E501
        :rtype: str
        """
        return self._redirect_view_url

    @redirect_view_url.setter
    def redirect_view_url(self, redirect_view_url):
        """Sets the redirect_view_url of this UIViewInfo.


        :param redirect_view_url: The redirect_view_url of this UIViewInfo.  # noqa: E501
        :type: str
        """

        self._redirect_view_url = redirect_view_url

    @property
    def edit_object_container(self):
        """Gets the edit_object_container of this UIViewInfo.  # noqa: E501


        :return: The edit_object_container of this UIViewInfo.  # noqa: E501
        :rtype: GenericEditIEditObjectContainer
        """
        return self._edit_object_container

    @edit_object_container.setter
    def edit_object_container(self, edit_object_container):
        """Sets the edit_object_container of this UIViewInfo.


        :param edit_object_container: The edit_object_container of this UIViewInfo.  # noqa: E501
        :type: GenericEditIEditObjectContainer
        """

        self._edit_object_container = edit_object_container

    @property
    def commands(self):
        """Gets the commands of this UIViewInfo.  # noqa: E501


        :return: The commands of this UIViewInfo.  # noqa: E501
        :rtype: list[UICommand]
        """
        return self._commands

    @commands.setter
    def commands(self, commands):
        """Sets the commands of this UIViewInfo.


        :param commands: The commands of this UIViewInfo.  # noqa: E501
        :type: list[UICommand]
        """

        self._commands = commands

    @property
    def tab_page_infos(self):
        """Gets the tab_page_infos of this UIViewInfo.  # noqa: E501


        :return: The tab_page_infos of this UIViewInfo.  # noqa: E501
        :rtype: list[UITabPageInfo]
        """
        return self._tab_page_infos

    @tab_page_infos.setter
    def tab_page_infos(self, tab_page_infos):
        """Sets the tab_page_infos of this UIViewInfo.


        :param tab_page_infos: The tab_page_infos of this UIViewInfo.  # noqa: E501
        :type: list[UITabPageInfo]
        """

        self._tab_page_infos = tab_page_infos

    @property
    def is_page_change_info(self):
        """Gets the is_page_change_info of this UIViewInfo.  # noqa: E501


        :return: The is_page_change_info of this UIViewInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_page_change_info

    @is_page_change_info.setter
    def is_page_change_info(self, is_page_change_info):
        """Sets the is_page_change_info of this UIViewInfo.


        :param is_page_change_info: The is_page_change_info of this UIViewInfo.  # noqa: E501
        :type: bool
        """

        self._is_page_change_info = is_page_change_info

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UIViewInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UIViewInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class PlayRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'controlling_user_id': 'str',
        'subtitle_stream_index': 'int',
        'audio_stream_index': 'int',
        'media_source_id': 'str',
        'start_index': 'int'
    }

    attribute_map = {
        'controlling_user_id': 'ControllingUserId',
        'subtitle_stream_index': 'SubtitleStreamIndex',
        'audio_stream_index': 'AudioStreamIndex',
        'media_source_id': 'MediaSourceId',
        'start_index': 'StartIndex'
    }

    def __init__(self, controlling_user_id=None, subtitle_stream_index=None, audio_stream_index=None, media_source_id=None, start_index=None):  # noqa: E501
        """PlayRequest - a model defined in Swagger"""  # noqa: E501
        self._controlling_user_id = None
        self._subtitle_stream_index = None
        self._audio_stream_index = None
        self._media_source_id = None
        self._start_index = None
        self.discriminator = None
        if controlling_user_id is not None:
            self.controlling_user_id = controlling_user_id
        if subtitle_stream_index is not None:
            self.subtitle_stream_index = subtitle_stream_index
        if audio_stream_index is not None:
            self.audio_stream_index = audio_stream_index
        if media_source_id is not None:
            self.media_source_id = media_source_id
        if start_index is not None:
            self.start_index = start_index

    @property
    def controlling_user_id(self):
        """Gets the controlling_user_id of this PlayRequest.  # noqa: E501

        The controlling user identifier.  # noqa: E501

        :return: The controlling_user_id of this PlayRequest.  # noqa: E501
        :rtype: str
        """
        return self._controlling_user_id

    @controlling_user_id.setter
    def controlling_user_id(self, controlling_user_id):
        """Sets the controlling_user_id of this PlayRequest.

        The controlling user identifier.  # noqa: E501

        :param controlling_user_id: The controlling_user_id of this PlayRequest.  # noqa: E501
        :type: str
        """

        self._controlling_user_id = controlling_user_id

    @property
    def subtitle_stream_index(self):
        """Gets the subtitle_stream_index of this PlayRequest.  # noqa: E501


        :return: The subtitle_stream_index of this PlayRequest.  # noqa: E501
        :rtype: int
        """
        return self._subtitle_stream_index

    @subtitle_stream_index.setter
    def subtitle_stream_index(self, subtitle_stream_index):
        """Sets the subtitle_stream_index of this PlayRequest.


        :param subtitle_stream_index: The subtitle_stream_index of this PlayRequest.  # noqa: E501
        :type: int
        """

        self._subtitle_stream_index = subtitle_stream_index

    @property
    def audio_stream_index(self):
        """Gets the audio_stream_index of this PlayRequest.  # noqa: E501


        :return: The audio_stream_index of this PlayRequest.  # noqa: E501
        :rtype: int
        """
        return self._audio_stream_index

    @audio_stream_index.setter
    def audio_stream_index(self, audio_stream_index):
        """Sets the audio_stream_index of this PlayRequest.


        :param audio_stream_index: The audio_stream_index of this PlayRequest.  # noqa: E501
        :type: int
        """

        self._audio_stream_index = audio_stream_index

    @property
    def media_source_id(self):
        """Gets the media_source_id of this PlayRequest.  # noqa: E501


        :return: The media_source_id of this PlayRequest.  # noqa: E501
        :rtype: str
        """
        return self._media_source_id

    @media_source_id.setter
    def media_source_id(self, media_source_id):
        """Sets the media_source_id of this PlayRequest.


        :param media_source_id: The media_source_id of this PlayRequest.  # noqa: E501
        :type: str
        """

        self._media_source_id = media_source_id

    @property
    def start_index(self):
        """Gets the start_index of this PlayRequest.  # noqa: E501


        :return: The start_index of this PlayRequest.  # noqa: E501
        :rtype: int
        """
        return self._start_index

    @start_index.setter
    def start_index(self, start_index):
        """Sets the start_index of this PlayRequest.


        :param start_index: The start_index of this PlayRequest.  # noqa: E501
        :type: int
        """

        self._start_index = start_index

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PlayRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlayRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
